/**
 * The result of calling the `fullname()` function.
 */
export declare type FullnameResult = {
    ambiguous: true;
    files: string[];
} | {
    ambiguous: false;
    file: string;
};
/**
 * Returns all paths currently in the index whose indexed state differs from
 * HEAD. Similar to the result of `git status`.
 */
export declare function getStagedPaths(): Promise<string[]>;
/**
 * Stage one or more paths with `git add`. If `paths` is an empty array, this
 * function becomes a no-op.
 */
export declare function stagePaths(paths: string[]): Promise<void>;
/**
 * Create a commit from staged files. Throws if no commit object is created.
 * `pipeOutput=false` will silence the underlying child process; it is `true` by
 * default.
 */
export declare function makeCommit(message: string, pipeOutput?: boolean): Promise<void>;
/**
 * Attempts to resolve an arbitrary `path` to a single full file path relative
 * to the repository root. If `path` resolves to no file, an error is thrown. If
 * `path` resolves to more than one file, `path` is considered "arbitrary" and
 * an array of files is returned.
 *
 * Note that this function expects all relevant paths to be tracked by git. If
 * `path` (or related files) are untracked, the result of this function is
 * undefined. In short: call `stagePaths(paths)` before calling
 * `fullname(paths[0])`.
 */
export declare function fullname(path: string): Promise<FullnameResult>;
/**
 * Find the non-root common ancestor of `paths` or return null.
 */
export declare function commonAncestor(paths: string[]): string | null;
/**
 * Returns true only if the current working directory is a git repository.
 */
export declare function isGitRepo(): Promise<boolean>;
